@@ -5,7 +5,7 @@
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version, or (at your opinion) under the terms 
+ *  (at your option) any later version, or (at your opinion) under the terms
  *  of the Mozilla Public License version 2.0.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -300,24 +300,7 @@ where
         }
 
         if oldp.is_some() {
-            unsafe {
-                let tmp = *self.heap.get_unchecked(pos);
-                while (pos > 0)
-                    && (self
-                        .map
-                        .get_index(*self.heap.get_unchecked(parent(pos)))
-                        .unwrap()
-                        .1
-                        < self.map.get_index(tmp).unwrap().1)
-                {
-                    *self.heap.get_unchecked_mut(pos) = *self.heap.get_unchecked(parent(pos));
-                    *self.qp.get_unchecked_mut(*self.heap.get_unchecked(pos)) = pos;
-                    pos = parent(pos);
-                }
-                *self.heap.get_unchecked_mut(pos) = tmp;
-                *self.qp.get_unchecked_mut(tmp) = pos;
-            }
-            self.heapify(pos);
+            self.up_heapify(pos);
             return oldp;
         }
         // get a reference to the priority
@@ -409,7 +392,7 @@ where
         I: Borrow<Q>,
         Q: Eq + Hash,
     {
-        let mut pos;
+        let pos;
         let r = if let Some((index, _, p)) = self.map.get_full_mut(item) {
             swap(p, &mut new_priority);
             pos = unsafe { *self.qp.get_unchecked(index) };
@@ -418,24 +401,7 @@ where
             return None;
         };
         if r.is_some() {
-            unsafe {
-                let tmp = *self.heap.get_unchecked(pos);
-                while (pos > 0)
-                    && (self
-                        .map
-                        .get_index(*self.heap.get_unchecked(parent(pos)))
-                        .unwrap()
-                        .1
-                        < self.map.get_index(tmp).unwrap().1)
-                {
-                    *self.heap.get_unchecked_mut(pos) = *self.heap.get_unchecked(parent(pos));
-                    *self.qp.get_unchecked_mut(*self.heap.get_unchecked(pos)) = pos;
-                    pos = parent(pos);
-                }
-                *self.heap.get_unchecked_mut(pos) = tmp;
-                *self.qp.get_unchecked_mut(tmp) = pos;
-            }
-            self.heapify(pos);
+            self.up_heapify(pos);
         }
         r
     }
@@ -457,24 +423,7 @@ where
             found = true;
         }
         if found {
-            unsafe {
-                let tmp = *self.heap.get_unchecked(pos);
-                while (pos > 0)
-                    && (self
-                        .map
-                        .get_index(*self.heap.get_unchecked(parent(pos)))
-                        .unwrap()
-                        .1
-                        < self.map.get_index(tmp).unwrap().1)
-                {
-                    *self.heap.get_unchecked_mut(pos) = *self.heap.get_unchecked(parent(pos));
-                    *self.qp.get_unchecked_mut(*self.heap.get_unchecked(pos)) = pos;
-                    pos = parent(pos);
-                }
-                *self.heap.get_unchecked_mut(pos) = tmp;
-                *self.qp.get_unchecked_mut(tmp) = pos;
-            }
-            self.heapify(pos);
+            self.up_heapify(pos);
         }
     }
 
@@ -549,7 +498,7 @@ where
                         *self.qp.get_unchecked_mut(*heap_pos) = pos;
                     }
                 }
-                self.heapify(parent(pos));
+                self.up_heapify(pos);
             }
         }
 
@@ -676,7 +625,7 @@ where
 
     /// Swap two elements keeping a consistent state.
     ///
-    /// Computes in **O(1)** time (average)
+    /// Computes in **O(1)** time
     fn swap(&mut self, a: usize, b: usize) {
         let (i, j) = unsafe { (*self.heap.get_unchecked(a), *self.heap.get_unchecked(b)) };
         self.heap.swap(a, b);
@@ -684,6 +633,8 @@ where
     }
 
     /// Internal function that restore the functional property of the heap
+    ///
+    /// Computes in **O(log(N))** time
     fn heapify(&mut self, i: usize) {
         let (mut l, mut r) = (left(i), right(i));
         let mut i = i;
@@ -739,8 +690,32 @@ where
         }
     }
 
+    fn up_heapify(&mut self, i: usize) {
+        let mut pos = i;
+        unsafe {
+            let tmp = *self.heap.get_unchecked(pos);
+            while (pos > 0)
+                && (self
+                    .map
+                    .get_index(*self.heap.get_unchecked(parent(pos)))
+                    .unwrap()
+                    .1
+                    < self.map.get_index(tmp).unwrap().1)
+            {
+                *self.heap.get_unchecked_mut(pos) = *self.heap.get_unchecked(parent(pos));
+                *self.qp.get_unchecked_mut(*self.heap.get_unchecked(pos)) = pos;
+                pos = parent(pos);
+            }
+            *self.heap.get_unchecked_mut(pos) = tmp;
+            *self.qp.get_unchecked_mut(tmp) = pos;
+        }
+        self.heapify(pos)
+    }
+
     /// Internal function that transform the `heap`
     /// vector in a heap with its properties
+    ///
+    /// Computes in **O(n)**
     pub(crate) fn heap_build(&mut self) {
         if self.size == 0 {
             return;
